==> 0.0.1.tar.gz: android/src/main/kotlin/shop/itbug/xiaomi_badger/service/NotifService.kt <==
package shop.itbug.xiaomi_badger.service

import android.annotation.TargetApi
import android.app.IntentService
import android.app.Notification
import android.app.NotificationChannel
import android.app.NotificationManager
import android.content.Context
import android.content.Intent
import android.os.Build
import android.util.Log
import me.leolin.shortcutbadger.ShortcutBadger


class NotifService : IntentService("BadgeIntentService") {
    private var notificationId = 0
    private var mNotificationManager: NotificationManager? = null

    override fun onCreate() {
        super.onCreate()
        mNotificationManager =
            getSystemService(Context.NOTIFICATION_SERVICE) as NotificationManager
    }

    override fun onHandleIntent(intent: Intent?) {
        if (intent != null) {
            val badgeCount = intent.getIntExtra("badgeCount", 0)
            val title = intent.getStringExtra("title")
            val content = intent.getStringExtra("content")
            mNotificationManager!!.cancel(notificationId)
            notificationId++
            val builder: Notification.Builder = Notification.Builder(applicationContext)
                .setContentTitle(title)
                .setContentText(content)
                .setSmallIcon(androidx.core.R.drawable.notification_bg)
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
                setupNotificationChannel()
                builder.setChannelId(NOTIFICATION_CHANNEL)
            }
            val notification = builder.build()
            Log.d("TAG","$badgeCount")
            ShortcutBadger.applyNotification(applicationContext, notification, badgeCount)
            mNotificationManager!!.notify(notificationId, notification)
        }
    }

    @TargetApi(Build.VERSION_CODES.O)
    private fun setupNotificationChannel() {
        val channel = NotificationChannel(
            NOTIFICATION_CHANNEL, "badge",
            NotificationManager.IMPORTANCE_DEFAULT
        )
        mNotificationManager!!.createNotificationChannel(channel)
    }

    companion object {
        private const val NOTIFICATION_CHANNEL = "badge"
    }
}

==> 0.0.3.tar.gz: android/src/main/kotlin/shop/itbug/xiaomi_badger/service/NotifService.kt <==
package shop.itbug.xiaomi_badger.service

import android.annotation.TargetApi
import android.app.IntentService
import android.app.Notification
import android.app.NotificationChannel
import android.app.NotificationManager
import android.content.Context
import android.content.Intent
import android.os.Build
import android.util.Log
import me.leolin.shortcutbadger.ShortcutBadger


class NotifService : IntentService("BadgeIntentService") {
    private var notificationId = 0
    private lateinit var mNotificationManager: NotificationManager

    override fun onCreate() {
        super.onCreate()
        mNotificationManager =
            getSystemService(Context.NOTIFICATION_SERVICE) as NotificationManager
    }

    override fun onHandleIntent(intent: Intent?) {
        if (intent != null) {
            val badgeCount = intent.getIntExtra("badgeCount", 0)
            val title = intent.getStringExtra("title")
            val content = intent.getStringExtra("content")
            mNotificationManager.cancel(notificationId)
            notificationId++
            val builder: Notification.Builder = Notification.Builder(applicationContext)
                .setContentTitle(title)
                .setContentText(content)
                .setSmallIcon(androidx.core.R.drawable.notification_bg)
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
                setupNotificationChannel()
                builder.setChannelId(NOTIFICATION_CHANNEL)
            }
            val notification = builder.build()
            Log.d("TAG","$badgeCount")
            ShortcutBadger.applyNotification(applicationContext, notification, badgeCount)
            mNotificationManager.notify(notificationId, notification)
        }
    }

    @TargetApi(Build.VERSION_CODES.O)
    private fun setupNotificationChannel() {
        val channel = NotificationChannel(
            NOTIFICATION_CHANNEL, "badge",
            NotificationManager.IMPORTANCE_DEFAULT
        )
        mNotificationManager.createNotificationChannel(channel)
    }

    companion object {
        private const val NOTIFICATION_CHANNEL = "badge"
    }
}
